@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
 module Family
-  class CelebrityFamily < Family::Family
+  class CelebrityFamily < ::Family::Family
   end
 end
